#include "mta-helper.fx"

// Sampler for the GTA texture
sampler Sampler0 = sampler_state
{
    Texture         = (gTexture0);
    MinFilter       = Linear;
    MagFilter       = Linear;
    MipFilter       = Linear;
};
 
struct VSInput
{
    float3 Position : POSITION0;
    float3 Normal : NORMAL0;
    float4 Diffuse : COLOR0;
    float2 TexCoord : TEXCOORD0;
};

struct PSInput
{
    float4 Position : POSITION0;
    float4 Diffuse : COLOR0;
    float2 TexCoord : TEXCOORD0;
};
 
PSInput VertexShaderFunction(VSInput VS)
{
    PSInput PS = (PSInput)0;
    PS.Position = mul(float4(VS.Position, 1), gWorldViewProjection);
    PS.TexCoord = VS.TexCoord;
    PS.Diffuse = MTACalcGTABuildingDiffuse( VS.Diffuse );
    return PS;
}

float4 PixelShaderFunction(PSInput PS) : COLOR0
{
    float4 texel = tex2D(Sampler0, PS.TexCoord);

	// Transform the final color depending in the light incidence threshold
	float3 pixel = texel.rgb;
	float4 diffuse = PS.Diffuse;
	
	// Transform the diffuse value to grayscale
	float intensity = diffuse.r * 0.2126 + diffuse.g * 0.7152 + diffuse.b * 0.0722;
	
	// Apply the right threshold
	if ( intensity <= 0.05 )
		pixel *= 0.1;
	else if ( intensity <= 0.5 )
		pixel *= 0.35;
	else if ( intensity <= 0.95 )
		pixel *= 0.7;

    return float4(pixel.rgb, texel.a);
}

technique toonshader
{
    pass P0
    {
        VertexShader = compile vs_3_0 VertexShaderFunction();
        PixelShader = compile ps_3_0 PixelShaderFunction();
    }
}
